@@ -52,15 +52,15 @@ usage() {
 	printf 'usage:\n'
 	printf '    %s -h\n' "$script"
 	printf '    %s --help\n' "$script"
-	printf '    %s [-a|-bD|-dB|-c] [-CeEfgGHilmMNrtTvz] [-O OPT_LEVEL] [-k KARATSUBA_LEN]\\\n' "$script"
+	printf '    %s [-a|-bD|-dB|-c] [-CeEfgGHilmMNPrtTvz] [-O OPT_LEVEL] [-k KARATSUBA_LEN]\\\n' "$script"
 	printf '       [-s SETTING] [-S SETTING] [-p TYPE]\n'
 	printf '    %s \\\n' "$script"
 	printf '       [--library|--bc-only --disable-dc|--dc-only --disable-bc|--coverage]  \\\n'
 	printf '       [--force --debug --disable-extra-math --disable-generated-tests]      \\\n'
 	printf '       [--disable-history --disable-man-pages --disable-nls --disable-strip] \\\n'
 	printf '       [--enable-editline] [--enable-readline] [--enable-internal-history]   \\\n'
-	printf '       [--install-all-locales] [--opt=OPT_LEVEL]                             \\\n'
-	printf '       [--karatsuba-len=KARATSUBA_LEN]                                       \\\n'
+	printf '       [--disable-problematic-tests] [--install-all-locales]                 \\\n'
+	printf '       [--opt=OPT_LEVEL] [--karatsuba-len=KARATSUBA_LEN]                     \\\n'
 	printf '       [--set-default-on=SETTING] [--set-default-off=SETTING]                \\\n'
 	printf '       [--predefined-build-type=TYPE]                                        \\\n'
 	printf '       [--prefix=PREFIX] [--bindir=BINDIR] [--datarootdir=DATAROOTDIR]       \\\n'
@@ -153,8 +153,12 @@ usage() {
 	printf '        quotes) This option *must* come before any others that might change the\n'
 	printf '        build options. Currently supported values for TYPE include: "BSD" (for\n'
 	printf '        matching the BSD bc and BSD dc), "GNU" (for matching the GNU bc and\n'
-	printf '        dc), and "GDH" (for the preferred build of the author, Gavin D. Howard).\n'
-	printf '        This will also automatically enable a release build.\n'
+	printf '        dc), "GDH" (for the preferred build of the author, Gavin D. Howard),\n'
+	printf '        and "DBG" (for the preferred debug build of the author). This will\n'
+	printf '        also automatically enable a release build (except for "DBG").\n'
+	printf '    -P, --disable-problematic-tests\n'
+	printf '        Disables problematic tests. These tests usually include tests that\n'
+	printf '        can cause a SIGKILL because of too much memory usage.\n'
 	printf '    -r, --enable-readline\n'
 	printf '        Enable the use of libreadline/readline. This is meant for those users\n'
 	printf '        that want vi-like or Emacs-like behavior in history. This option is\n'
@@ -599,9 +603,9 @@ gen_err_tests() {
 
 	for _gen_err_tests_t in $_gen_err_tests_fs; do
 
-		printf 'test_%s_error_%s:\n\t@export BC_TEST_OUTPUT_DIR="%s/tests"; sh $(TESTSDIR)/error.sh %s %s %s\n\n' \
+		printf 'test_%s_error_%s:\n\t@export BC_TEST_OUTPUT_DIR="%s/tests"; sh $(TESTSDIR)/error.sh %s %s %s %s\n\n' \
 			"$_gen_err_tests_name" "$_gen_err_tests_t" "$builddir" "$_gen_err_tests_name" \
-			"$_gen_err_tests_t" "$*" >> "Makefile"
+			"$_gen_err_tests_t" "$problematic_tests" "$*" >> "Makefile"
 
 	done
 
@@ -710,7 +714,7 @@ predefined_build() {
 			hist=1
 			hist_impl="editline"
 			extra_math=1
-			generate_tests=0
+			generate_tests=$generate_tests
 			install_manpages=0
 			nls=1
 			force=0
@@ -743,7 +747,7 @@ predefined_build() {
 			hist=1
 			hist_impl="internal"
 			extra_math=1
-			generate_tests=1
+			generate_tests=$generate_tests
 			install_manpages=1
 			nls=1
 			force=0
@@ -768,7 +772,7 @@ predefined_build() {
 			dc_default_digit_clamp=0;;
 
 		GDH)
-			CFLAGS="-flto -Weverything -Wno-padded -Wno-gnu-label-as-value -Werror -pedantic -std=c11"
+			CFLAGS="-flto -Weverything -Wno-padded -Werror -pedantic -std=c11"
 			bc_only=0
 			dc_only=0
 			coverage=0
@@ -801,7 +805,41 @@ predefined_build() {
 			bc_default_digit_clamp=1
 			dc_default_digit_clamp=1;;
 
-		?|'') usage "Invalid user build: \"$_predefined_build_type\". Accepted types are BSD, GNU, and GDH.";;
+		DBG)
+			CFLAGS="-Weverything -Wno-padded -Werror -pedantic -std=c11"
+			bc_only=0
+			dc_only=0
+			coverage=0
+			debug=1
+			optimization="0"
+			hist=1
+			hist_impl="internal"
+			extra_math=1
+			generate_tests=1
+			install_manpages=1
+			nls=1
+			force=0
+			strip_bin=1
+			all_locales=0
+			library=0
+			fuzz=0
+			time_tests=0
+			vg=0
+			memcheck=1
+			clean=1
+			bc_default_banner=1
+			bc_default_sigint_reset=1
+			dc_default_sigint_reset=1
+			bc_default_tty_mode=1
+			dc_default_tty_mode=1
+			bc_default_prompt=""
+			dc_default_prompt=""
+			bc_default_expr_exit=0
+			dc_default_expr_exit=0
+			bc_default_digit_clamp=1
+			dc_default_digit_clamp=1;;
+
+		?|'') usage "Invalid user build: \"$_predefined_build_type\". Accepted types are BSD, GNU, GDH, DBG.";;
 
 	esac
 }
@@ -854,6 +892,7 @@ time_tests=0
 vg=0
 memcheck=0
 clean=1
+problematic_tests=1
 
 # The empty strings are because they depend on TTY mode. If they are directly
 # set, though, they will be integers. We test for empty strings later.
@@ -872,7 +911,7 @@ dc_default_digit_clamp=0
 # getopts is a POSIX utility, but it cannot handle long options. Thus, the
 # handling of long options is done by hand, and that's the reason that short and
 # long options cannot be mixed.
-while getopts "abBcdDeEfgGhHik:lMmNO:p:rS:s:tTvz-" opt; do
+while getopts "abBcdDeEfgGhHik:lMmNO:p:PrS:s:tTvz-" opt; do
 
 	case "$opt" in
 		a) library=1 ;;
@@ -897,6 +936,7 @@ while getopts "abBcdDeEfgGhHik:lMmNO:p:rS:s:tTvz-" opt; do
 		N) nls=0 ;;
 		O) optimization="$OPTARG" ;;
 		p) predefined_build "$OPTARG" ;;
+		P) problematic_tests=0 ;;
 		r) hist_impl="readline" ;;
 		S) set_default 0 "$OPTARG" ;;
 		s) set_default 1 "$OPTARG" ;;
@@ -1030,6 +1070,7 @@ while getopts "abBcdDeEfgGhHik:lMmNO:p:rS:s:tTvz-" opt; do
 				disable-man-pages) install_manpages=0 ;;
 				disable-nls) nls=0 ;;
 				disable-strip) strip_bin=0 ;;
+				disable-problematic-tests) problematic_tests=0 ;;
 				enable-editline) hist_impl="editline" ;;
 				enable-readline) hist_impl="readline" ;;
 				enable-internal-history) hist_impl="internal" ;;
@@ -1048,6 +1089,8 @@ while getopts "abBcdDeEfgGhHik:lMmNO:p:rS:s:tTvz-" opt; do
 					usage "No arg allowed for --$arg option" ;;
 				disable-man-pages* | disable-nls* | disable-strip*)
 					usage "No arg allowed for --$arg option" ;;
+				disable-problematic-tests*)
+					usage "No arg allowed for --$arg option" ;;
 				enable-fuzz-mode* | enable-test-timing* | enable-valgrind*)
 					usage "No arg allowed for --$arg option" ;;
 				enable-memcheck* | install-all-locales*)
@@ -1176,10 +1219,10 @@ executable="BC_EXEC"
 
 tests="test_bc timeconst test_dc"
 
-bc_test="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/all.sh bc $extra_math 1 $generate_tests $time_tests \$(BC_EXEC)"
-bc_test_np="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/all.sh -n bc $extra_math 1 $generate_tests $time_tests \$(BC_EXEC)"
-dc_test="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/all.sh dc $extra_math 1 $generate_tests $time_tests \$(DC_EXEC)"
-dc_test_np="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/all.sh -n dc $extra_math 1 $generate_tests $time_tests \$(DC_EXEC)"
+bc_test="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/all.sh bc $extra_math 1 $generate_tests $problematic_tests $time_tests \$(BC_EXEC)"
+bc_test_np="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/all.sh -n bc $extra_math 1 $generate_tests $problematic_tests $time_tests \$(BC_EXEC)"
+dc_test="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/all.sh dc $extra_math 1 $generate_tests $problematic_tests $time_tests \$(DC_EXEC)"
+dc_test_np="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/all.sh -n dc $extra_math 1 $generate_tests $problematic_tests $time_tests \$(DC_EXEC)"
 
 timeconst="@export BC_TEST_OUTPUT_DIR=\"$builddir/tests\"; \$(TESTSDIR)/bc/timeconst.sh \$(TESTSDIR)/bc/scripts/timeconst.bc \$(BC_EXEC)"
 
@@ -1469,7 +1512,7 @@ if [ "$nls" -ne 0 ]; then
 		flags="$flags -Wno-unreachable-code"
 	fi
 
-	"$CC" $CPPFLAGS $CFLAGS $flags -c "$scriptdir/src/vm.c" -o "./vm.o" > /dev/null #2>&1
+	"$CC" $CPPFLAGS $CFLAGS $flags -c "$scriptdir/src/vm.c" -o "./vm.o" > /dev/null 2>&1
 
 	err="$?"
 
