@@ -36,6 +36,11 @@
 #ifndef BC_BCL_H
 #define BC_BCL_H
 
+#include <stdbool.h>
+#include <stdlib.h>
+#include <limits.h>
+#include <stdint.h>
+
 #ifdef _WIN32
 #include <Windows.h>
 #include <BaseTsd.h>
@@ -43,44 +48,8 @@
 #include <io.h>
 #endif // _WIN32
 
-#include <stdbool.h>
-#include <stdlib.h>
-#include <limits.h>
-#include <stdint.h>
-#include <sys/types.h>
-
-// Windows has deprecated isatty() and the rest of these. Or doesn't have them.
-// So these are just fixes for Windows.
 #ifdef _WIN32
-
-// This one is special. Windows did not like me defining an
-// inline function that was not given a definition in a header
-// file. This suppresses that by making inline functions non-inline.
-#define inline
-
-#define restrict __restrict
-#define strdup _strdup
-#define write(f, b, s) _write((f), (b), (unsigned int) (s))
-#define read(f, b, s) _read((f), (b), (unsigned int) (s))
-#define close _close
-#define open(f, n, m) \
-	_sopen_s((f), (n), (m) | _O_BINARY, _SH_DENYNO, _S_IREAD | _S_IWRITE)
-#define sigjmp_buf jmp_buf
-#define sigsetjmp(j, s) setjmp(j)
-#define siglongjmp longjmp
-#define isatty _isatty
-#define STDIN_FILENO _fileno(stdin)
-#define STDOUT_FILENO _fileno(stdout)
-#define STDERR_FILENO _fileno(stderr)
 #define ssize_t SSIZE_T
-#define S_ISDIR(m) ((m) & _S_IFDIR)
-#define O_RDONLY _O_RDONLY
-#define stat _stat
-#define fstat _fstat
-#define BC_FILE_SEP '\\'
-
-#else // _WIN32
-#define BC_FILE_SEP '/'
 #endif // _WIN32
 
 #define BCL_SEED_ULONGS (4)
@@ -129,8 +98,8 @@ typedef uint32_t BclRandInt;
 
 #if BC_ENABLE_LIBRARY
 
-typedef enum BclError {
-
+typedef enum BclError
+{
 	BCL_ERROR_NONE,
 
 	BCL_ERROR_INVALID_NUM,
@@ -151,8 +120,8 @@ typedef enum BclError {
 
 } BclError;
 
-typedef struct BclNumber {
-
+typedef struct BclNumber
+{
 	size_t i;
 
 } BclNumber;
@@ -161,81 +130,185 @@ struct BclCtxt;
 
 typedef struct BclCtxt* BclContext;
 
-void bcl_handleSignal(void);
-bool bcl_running(void);
+BclError
+bcl_start(void);
 
-BclError bcl_init(void);
-void bcl_free(void);
+void
+bcl_end(void);
 
-bool bcl_abortOnFatalError(void);
-void bcl_setAbortOnFatalError(bool abrt);
-bool bcl_leadingZeroes(void);
-void bcl_setLeadingZeroes(bool leadingZeroes);
+BclError
+bcl_init(void);
 
-void bcl_gc(void);
+void
+bcl_free(void);
 
-BclError bcl_pushContext(BclContext ctxt);
-void bcl_popContext(void);
-BclContext bcl_context(void);
+bool
+bcl_abortOnFatalError(void);
 
-BclContext bcl_ctxt_create(void);
-void bcl_ctxt_free(BclContext ctxt);
-void bcl_ctxt_freeNums(BclContext ctxt);
+void
+bcl_setAbortOnFatalError(bool abrt);
 
-size_t bcl_ctxt_scale(BclContext ctxt);
-void bcl_ctxt_setScale(BclContext ctxt, size_t scale);
-size_t bcl_ctxt_ibase(BclContext ctxt);
-void bcl_ctxt_setIbase(BclContext ctxt, size_t ibase);
-size_t bcl_ctxt_obase(BclContext ctxt);
-void bcl_ctxt_setObase(BclContext ctxt, size_t obase);
+bool
+bcl_leadingZeroes(void);
 
-BclError bcl_err(BclNumber n);
+void
+bcl_setLeadingZeroes(bool leadingZeroes);
 
-BclNumber bcl_num_create(void);
-void bcl_num_free(BclNumber n);
+bool
+bcl_digitClamp(void);
 
-bool bcl_num_neg(BclNumber n);
-void bcl_num_setNeg(BclNumber n, bool neg);
-size_t bcl_num_scale(BclNumber n);
-BclError bcl_num_setScale(BclNumber n, size_t scale);
-size_t bcl_num_len(BclNumber n);
+void
+bcl_setDigitClamp(bool digitClamp);
 
-BclError bcl_copy(BclNumber d, BclNumber s);
-BclNumber bcl_dup(BclNumber s);
+void
+bcl_gc(void);
 
-BclError bcl_bigdig(BclNumber n, BclBigDig *result);
-BclNumber bcl_bigdig2num(BclBigDig val);
+BclError
+bcl_pushContext(BclContext ctxt);
 
-BclNumber bcl_add(BclNumber a, BclNumber b);
-BclNumber bcl_sub(BclNumber a, BclNumber b);
-BclNumber bcl_mul(BclNumber a, BclNumber b);
-BclNumber bcl_div(BclNumber a, BclNumber b);
-BclNumber bcl_mod(BclNumber a, BclNumber b);
-BclNumber bcl_pow(BclNumber a, BclNumber b);
-BclNumber bcl_lshift(BclNumber a, BclNumber b);
-BclNumber bcl_rshift(BclNumber a, BclNumber b);
-BclNumber bcl_sqrt(BclNumber a);
-BclError bcl_divmod(BclNumber a, BclNumber b, BclNumber *c, BclNumber *d);
-BclNumber bcl_modexp(BclNumber a, BclNumber b, BclNumber c);
+void
+bcl_popContext(void);
 
-ssize_t bcl_cmp(BclNumber a, BclNumber b);
+BclContext
+bcl_context(void);
 
-void bcl_zero(BclNumber n);
-void bcl_one(BclNumber n);
+BclContext
+bcl_ctxt_create(void);
 
-BclNumber bcl_parse(const char *restrict val);
-char* bcl_string(BclNumber n);
+void
+bcl_ctxt_free(BclContext ctxt);
 
-BclNumber bcl_irand(BclNumber a);
-BclNumber bcl_frand(size_t places);
-BclNumber bcl_ifrand(BclNumber a, size_t places);
+void
+bcl_ctxt_freeNums(BclContext ctxt);
 
-BclError bcl_rand_seedWithNum(BclNumber n);
-BclError bcl_rand_seed(unsigned char seed[BCL_SEED_SIZE]);
-void bcl_rand_reseed(void);
-BclNumber bcl_rand_seed2num(void);
-BclRandInt bcl_rand_int(void);
-BclRandInt bcl_rand_bounded(BclRandInt bound);
+size_t
+bcl_ctxt_scale(BclContext ctxt);
+
+void
+bcl_ctxt_setScale(BclContext ctxt, size_t scale);
+
+size_t
+bcl_ctxt_ibase(BclContext ctxt);
+
+void
+bcl_ctxt_setIbase(BclContext ctxt, size_t ibase);
+
+size_t
+bcl_ctxt_obase(BclContext ctxt);
+
+void
+bcl_ctxt_setObase(BclContext ctxt, size_t obase);
+
+BclError
+bcl_err(BclNumber n);
+
+BclNumber
+bcl_num_create(void);
+
+void
+bcl_num_free(BclNumber n);
+
+bool
+bcl_num_neg(BclNumber n);
+
+void
+bcl_num_setNeg(BclNumber n, bool neg);
+
+size_t
+bcl_num_scale(BclNumber n);
+
+BclError
+bcl_num_setScale(BclNumber n, size_t scale);
+
+size_t
+bcl_num_len(BclNumber n);
+
+BclError
+bcl_copy(BclNumber d, BclNumber s);
+
+BclNumber
+bcl_dup(BclNumber s);
+
+BclError
+bcl_bigdig(BclNumber n, BclBigDig* result);
+
+BclNumber
+bcl_bigdig2num(BclBigDig val);
+
+BclNumber
+bcl_add(BclNumber a, BclNumber b);
+
+BclNumber
+bcl_sub(BclNumber a, BclNumber b);
+
+BclNumber
+bcl_mul(BclNumber a, BclNumber b);
+
+BclNumber
+bcl_div(BclNumber a, BclNumber b);
+
+BclNumber
+bcl_mod(BclNumber a, BclNumber b);
+
+BclNumber
+bcl_pow(BclNumber a, BclNumber b);
+
+BclNumber
+bcl_lshift(BclNumber a, BclNumber b);
+
+BclNumber
+bcl_rshift(BclNumber a, BclNumber b);
+
+BclNumber
+bcl_sqrt(BclNumber a);
+
+BclError
+bcl_divmod(BclNumber a, BclNumber b, BclNumber* c, BclNumber* d);
+
+BclNumber
+bcl_modexp(BclNumber a, BclNumber b, BclNumber c);
+
+ssize_t
+bcl_cmp(BclNumber a, BclNumber b);
+
+void
+bcl_zero(BclNumber n);
+
+void
+bcl_one(BclNumber n);
+
+BclNumber
+bcl_parse(const char* restrict val);
+
+char*
+bcl_string(BclNumber n);
+
+BclNumber
+bcl_irand(BclNumber a);
+
+BclNumber
+bcl_frand(size_t places);
+
+BclNumber
+bcl_ifrand(BclNumber a, size_t places);
+
+BclError
+bcl_rand_seedWithNum(BclNumber n);
+
+BclError
+bcl_rand_seed(unsigned char seed[BCL_SEED_SIZE]);
+
+void
+bcl_rand_reseed(void);
+
+BclNumber
+bcl_rand_seed2num(void);
+
+BclRandInt
+bcl_rand_int(void);
+
+BclRandInt
+bcl_rand_bounded(BclRandInt bound);
 
 #endif // BC_ENABLE_LIBRARY
 
