@@ -46,26 +46,27 @@
  * Lexes an identifier, which may be a keyword.
  * @param l  The lexer.
  */
-static void bc_lex_identifier(BcLex *l) {
-
+static void
+bc_lex_identifier(BcLex* l)
+{
 	// We already passed the first character, so we need to be sure to include
 	// it.
-	const char *buf = l->buf + l->i - 1;
+	const char* buf = l->buf + l->i - 1;
 	size_t i;
 
 	// This loop is simply checking for keywords.
-	for (i = 0; i < bc_lex_kws_len; ++i) {
-
-		const BcLexKeyword *kw = bc_lex_kws + i;
+	for (i = 0; i < bc_lex_kws_len; ++i)
+	{
+		const BcLexKeyword* kw = bc_lex_kws + i;
 		size_t n = BC_LEX_KW_LEN(kw);
 
-		if (!strncmp(buf, kw->name, n) && !isalnum(buf[n]) && buf[n] != '_') {
-
+		if (!strncmp(buf, kw->name, n) && !isalnum(buf[n]) && buf[n] != '_')
+		{
 			// If the keyword has been redefined, and redefinition is allowed
 			// (it is not allowed for builtin libraries), break out of the loop
 			// and use it as a name. This depends on the argument parser to
 			// ensure that only non-POSIX keywords get redefined.
-			if (!vm.no_redefine && vm.redefined_kws[i]) break;
+			if (!vm->no_redefine && vm->redefined_kws[i]) break;
 
 			l->t = BC_LEX_KW_AUTO + (BcLexType) i;
 
@@ -87,7 +88,9 @@ static void bc_lex_identifier(BcLex *l) {
 	// POSIX doesn't allow identifiers that are more than one character, so we
 	// might have to warn or error here too.
 	if (BC_ERR(l->str.len - 1 > 1))
+	{
 		bc_lex_verr(l, BC_ERR_POSIX_NAME_LEN, l->str.v);
+	}
 }
 
 /**
@@ -95,35 +98,42 @@ static void bc_lex_identifier(BcLex *l) {
  * to be balanced.
  * @param l  The lexer.
  */
-static void bc_lex_string(BcLex *l) {
-
+static void
+bc_lex_string(BcLex* l)
+{
 	// We need to keep track of newlines to increment them properly.
 	size_t len, nlines, i;
-	const char *buf;
+	const char* buf;
 	char c;
 	bool got_more;
 
 	l->t = BC_LEX_STR;
 
-	do {
-
+	do
+	{
 		nlines = 0;
 		buf = l->buf;
 		got_more = false;
 
-		assert(!vm.is_stdin || buf == vm.buffer.v);
+		assert(vm->mode != BC_MODE_STDIN || buf == vm->buffer.v);
 
 		// Fortunately for us, bc doesn't escape quotes. Instead, the equivalent
 		// is '\q', which makes this loop simpler.
-		for (i = l->i; (c = buf[i]) && c != '"'; ++i) nlines += (c == '\n');
+		for (i = l->i; (c = buf[i]) && c != '"'; ++i)
+		{
+			nlines += (c == '\n');
+		}
 
-		if (BC_ERR(c == '\0') && !vm.eof && l->is_stdin)
+		if (BC_ERR(c == '\0') && !vm->eof && l->mode != BC_MODE_FILE)
+		{
 			got_more = bc_lex_readLine(l);
-
-	} while (got_more && c != '"');
+		}
+	}
+	while (got_more && c != '"');
 
 	// If the string did not end properly, barf.
-	if (c != '"') {
+	if (c != '"')
+	{
 		l->i = i;
 		bc_lex_err(l, BC_ERR_PARSE_STRING);
 	}
@@ -143,16 +153,20 @@ static void bc_lex_string(BcLex *l) {
  * @param with     The token to assign if it is an assignment operator.
  * @param without  The token to assign if it is not an assignment operator.
  */
-static void bc_lex_assign(BcLex *l, BcLexType with, BcLexType without) {
-	if (l->buf[l->i] == '=') {
+static void
+bc_lex_assign(BcLex* l, BcLexType with, BcLexType without)
+{
+	if (l->buf[l->i] == '=')
+	{
 		l->i += 1;
 		l->t = with;
 	}
 	else l->t = without;
 }
 
-void bc_lex_token(BcLex *l) {
-
+void
+bc_lex_token(BcLex* l)
+{
 	// We increment here. This means that all lexing needs to take that into
 	// account, such as when parsing an identifier. If we don't, the first
 	// character of every identifier would be missing.
@@ -161,8 +175,8 @@ void bc_lex_token(BcLex *l) {
 	BC_SIG_ASSERT_LOCKED;
 
 	// This is the workhorse of the lexer.
-	switch (c) {
-
+	switch (c)
+	{
 		case '\0':
 		case '\n':
 		case '\t':
@@ -182,7 +196,9 @@ void bc_lex_token(BcLex *l) {
 
 			// POSIX doesn't allow boolean not.
 			if (l->t == BC_LEX_OP_BOOL_NOT)
+			{
 				bc_lex_verr(l, BC_ERR_POSIX_BOOL, "!");
+			}
 
 			break;
 		}
@@ -213,8 +229,8 @@ void bc_lex_token(BcLex *l) {
 
 			// Either we have boolean and or an error. And boolean and is not
 			// allowed by POSIX.
-			if (BC_NO_ERR(c2 == '&')) {
-
+			if (BC_NO_ERR(c2 == '&'))
+			{
 				bc_lex_verr(l, BC_ERR_POSIX_BOOL, "&&");
 
 				l->i += 1;
@@ -255,7 +271,8 @@ void bc_lex_token(BcLex *l) {
 			c2 = l->buf[l->i];
 
 			// Have to check for increment first.
-			if (c2 == '+') {
+			if (c2 == '+')
+			{
 				l->i += 1;
 				l->t = BC_LEX_OP_INC;
 			}
@@ -274,7 +291,8 @@ void bc_lex_token(BcLex *l) {
 			c2 = l->buf[l->i];
 
 			// Have to check for decrement first.
-			if (c2 == '-') {
+			if (c2 == '-')
+			{
 				l->i += 1;
 				l->t = BC_LEX_OP_DEC;
 			}
@@ -288,7 +306,8 @@ void bc_lex_token(BcLex *l) {
 
 			// If it's alone, it's an alias for last.
 			if (BC_LEX_NUM_CHAR(c2, true, false)) bc_lex_number(l, c);
-			else {
+			else
+			{
 				l->t = BC_LEX_KW_LAST;
 				bc_lex_err(l, BC_ERR_POSIX_DOT);
 			}
@@ -299,7 +318,7 @@ void bc_lex_token(BcLex *l) {
 		case '/':
 		{
 			c2 = l->buf[l->i];
-			if (c2 =='*') bc_lex_comment(l);
+			if (c2 == '*') bc_lex_comment(l);
 			else bc_lex_assign(l, BC_LEX_OP_ASSIGN_DIVIDE, BC_LEX_OP_DIVIDE);
 			break;
 		}
@@ -361,7 +380,8 @@ void bc_lex_token(BcLex *l) {
 			c2 = l->buf[l->i];
 
 			// Check for shift.
-			if (c2 == '<') {
+			if (c2 == '<')
+			{
 				l->i += 1;
 				bc_lex_assign(l, BC_LEX_OP_ASSIGN_LSHIFT, BC_LEX_OP_LSHIFT);
 				break;
@@ -383,7 +403,8 @@ void bc_lex_token(BcLex *l) {
 			c2 = l->buf[l->i];
 
 			// Check for shift.
-			if (c2 == '>') {
+			if (c2 == '>')
+			{
 				l->i += 1;
 				bc_lex_assign(l, BC_LEX_OP_ASSIGN_RSHIFT, BC_LEX_OP_RSHIFT);
 				break;
@@ -403,7 +424,8 @@ void bc_lex_token(BcLex *l) {
 		case '\\':
 		{
 			// In bc, a backslash+newline is whitespace.
-			if (BC_NO_ERR(l->buf[l->i] == '\n')) {
+			if (BC_NO_ERR(l->buf[l->i] == '\n'))
+			{
 				l->i += 1;
 				l->t = BC_LEX_WHITESPACE;
 			}
@@ -460,8 +482,8 @@ void bc_lex_token(BcLex *l) {
 			c2 = l->buf[l->i];
 
 			// Once again, boolean or is not allowed by POSIX.
-			if (BC_NO_ERR(c2 == '|')) {
-
+			if (BC_NO_ERR(c2 == '|'))
+			{
 				bc_lex_verr(l, BC_ERR_POSIX_BOOL, "||");
 
 				l->i += 1;
