@@ -719,6 +719,8 @@ const char* bc_inst_names[] = {
 	"BC_INST_SCALE_FUNC",
 	"BC_INST_SQRT",
 	"BC_INST_ABS",
+	"BC_INST_IS_NUMBER",
+	"BC_INST_IS_STRING",
 #if BC_ENABLE_EXTRA_MATH
 	"BC_INST_IRAND",
 #endif // BC_ENABLE_EXTRA_MATH
@@ -816,6 +818,8 @@ const BcLexKeyword bc_lex_kws[] = {
 	BC_LEX_KW_ENTRY("print", 5, false),
 	BC_LEX_KW_ENTRY("sqrt", 4, true),
 	BC_LEX_KW_ENTRY("abs", 3, false),
+	BC_LEX_KW_ENTRY("is_number", 9, false),
+	BC_LEX_KW_ENTRY("is_string", 9, false),
 #if BC_ENABLE_EXTRA_MATH
 	BC_LEX_KW_ENTRY("irand", 5, false),
 #endif // BC_ENABLE_EXTRA_MATH
@@ -888,13 +892,13 @@ const uint8_t bc_parse_exprs[] = {
 	BC_PARSE_EXPR_ENTRY(false, true, true, true, true, true, true, false),
 
 	// Starts with BC_LEX_KW_SQRT.
-	BC_PARSE_EXPR_ENTRY(true, true, true, true, true, true, false, true),
-
-	// Starts with BC_LEX_KW_MAXIBASE.
 	BC_PARSE_EXPR_ENTRY(true, true, true, true, true, true, true, true),
 
-	// Starts with BC_LEX_KW_STREAM.
-	BC_PARSE_EXPR_ENTRY(false, false, 0, 0, 0, 0, 0, 0)
+	// Starts with BC_LEX_KW_QUIT.
+	BC_PARSE_EXPR_ENTRY(false, true, true, true, true, true, true, true),
+
+	// Starts with BC_LEX_KW_GLOBAL_STACKS.
+	BC_PARSE_EXPR_ENTRY(true, true, false, false, 0, 0, 0, 0)
 
 #else // BC_ENABLE_EXTRA_MATH
 
@@ -911,15 +915,19 @@ const uint8_t bc_parse_exprs[] = {
 	BC_PARSE_EXPR_ENTRY(false, false, true, true, true, true, true, false),
 
 	// Starts with BC_LEX_KW_SQRT.
-	BC_PARSE_EXPR_ENTRY(true, true, true, true, true, false, true, true),
+	BC_PARSE_EXPR_ENTRY(true, true, true, true, true, true, true, false),
 
-	// Starts with BC_LEX_KW_MAXSCALE,
-	BC_PARSE_EXPR_ENTRY(true, true, true, true, true, false, false, 0)
+	// Starts with BC_LEX_KW_MAXIBASE.
+	BC_PARSE_EXPR_ENTRY(true, true, true, true, true, true, true, false),
+
+	// Starts with  BC_LEX_KW_ELSE.
+	BC_PARSE_EXPR_ENTRY(false, 0, 0, 0, 0, 0, 0, 0)
 
 #endif // BC_ENABLE_EXTRA_MATH
 };
 
-/// An array of data for operators that correspond to token types.
+/// An array of data for operators that correspond to token types. Note that a
+/// lower precedence *value* means a higher precedence.
 const uchar bc_parse_ops[] = {
 	BC_PARSE_OP(0, false), BC_PARSE_OP(0, false), BC_PARSE_OP(1, false),
 	BC_PARSE_OP(1, false),
@@ -1122,8 +1130,8 @@ const uchar dc_lex_tokens[] = {
 	BC_LEX_KW_QUIT,
 	BC_LEX_SWAP,
 	BC_LEX_OP_ASSIGN,
-	BC_LEX_INVALID,
-	BC_LEX_INVALID,
+	BC_LEX_KW_IS_STRING,
+	BC_LEX_KW_IS_NUMBER,
 	BC_LEX_KW_SQRT,
 	BC_LEX_INVALID,
 	BC_LEX_EXECUTE,
@@ -1137,7 +1145,7 @@ const uchar dc_lex_tokens[] = {
 };
 
 /// A list of instructions that correspond to lex tokens. If an entry is
-/// BC_INST_INVALID, that lex token needs extra parsing in the dc parser.
+/// @a BC_INST_INVALID, that lex token needs extra parsing in the dc parser.
 /// Otherwise, the token can trivially be replaced by the entry. This needs to
 /// be updated if the tokens change.
 const uchar dc_parse_insts[] = {
@@ -1180,7 +1188,7 @@ const uchar dc_parse_insts[] = {
 	BC_INST_SEED,
 #endif // BC_ENABLE_EXTRA_MATH
 	BC_INST_LENGTH,       BC_INST_PRINT,        BC_INST_SQRT,
-	BC_INST_ABS,
+	BC_INST_ABS,          BC_INST_IS_NUMBER,    BC_INST_IS_STRING,
 #if BC_ENABLE_EXTRA_MATH
 	BC_INST_IRAND,
 #endif // BC_ENABLE_EXTRA_MATH
