@@ -488,9 +488,16 @@ bc_vm_setenvFlag(const char* const var, int def, uint16_t flag)
 /**
  * Parses the arguments in {B,D]C_ENV_ARGS.
  * @param env_args_name  The environment variable to use.
+ * @param scale          A pointer to return the scale that the arguments set,
+ *                       if any.
+ * @param ibase          A pointer to return the ibase that the arguments set,
+ *                       if any.
+ * @param obase          A pointer to return the obase that the arguments set,
+ *                       if any.
  */
 static void
-bc_vm_envArgs(const char* const env_args_name)
+bc_vm_envArgs(const char* const env_args_name, BcBigDig* scale, BcBigDig* ibase,
+              BcBigDig* obase)
 {
 	char *env_args = bc_vm_getenv(env_args_name), *buf, *start;
 	char instr = '\0';
@@ -568,7 +575,7 @@ bc_vm_envArgs(const char* const env_args_name)
 
 	// Parse the arguments.
 	bc_args((int) vm->env_args.len - 1, bc_vec_item(&vm->env_args, 0), false,
-	        BC_PROG_SCALE(&vm->prog));
+	        scale, ibase, obase);
 }
 
 /**
@@ -642,9 +649,7 @@ bc_vm_shutdown(void)
 	bc_parse_free(&vm->prs);
 	bc_program_free(&vm->prog);
 
-	bc_slabvec_free(&vm->other_slabs);
-	bc_slabvec_free(&vm->main_slabs);
-	bc_slabvec_free(&vm->main_const_slab);
+	bc_slabvec_free(&vm->slabs);
 #endif // !BC_ENABLE_LIBRARY
 
 	bc_vm_freeTemps();
@@ -959,30 +964,17 @@ bc_vm_clean(void)
 	// constants, and code.
 	if (good && vm->prog.stack.len == 1 && ip->idx == f->code.len)
 	{
+		// XXX: Nothing can be popped in dc. Deal with it.
+
 #if BC_ENABLED
 		if (BC_IS_BC)
 		{
+			// XXX: you cannot delete strings, functions, or constants in bc.
+			// Deal with it.
 			bc_vec_popAll(&f->labels);
-			bc_vec_popAll(&f->strs);
-			bc_vec_popAll(&f->consts);
-
-			// I can't clear out the other_slabs because it has functions,
-			// consts, strings, vars, and arrays. It has strings from *other*
-			// functions, specifically.
-			bc_slabvec_clear(&vm->main_const_slab);
-			bc_slabvec_clear(&vm->main_slabs);
 		}
 #endif // BC_ENABLED
 
-#if DC_ENABLED
-		// Note to self: you cannot delete strings and functions. Deal with it.
-		if (BC_IS_DC)
-		{
-			bc_vec_popAll(vm->prog.consts);
-			bc_slabvec_clear(&vm->main_const_slab);
-		}
-#endif // DC_ENABLED
-
 		bc_vec_popAll(&f->code);
 
 		ip->idx = 0;
@@ -991,33 +983,21 @@ bc_vm_clean(void)
 
 /**
  * Process a bunch of text.
- * @param text      The text to process.
- * @param is_stdin  True if the text came from stdin, false otherwise.
- * @param is_exprs  True if the text is from command-line expressions, false
- *                  otherwise.
+ * @param text  The text to process.
+ * @param mode  The mode to process in.
  */
 static void
-bc_vm_process(const char* text, bool is_stdin, bool is_exprs)
+bc_vm_process(const char* text, BcMode mode)
 {
 	// Set up the parser.
-	bc_parse_text(&vm->prs, text, is_stdin, is_exprs);
+	bc_parse_text(&vm->prs, text, mode);
 
-	do
+	while (vm->prs.l.t != BC_LEX_EOF)
 	{
+		// Parsing requires a signal lock. We also don't parse everything; we
+		// want to execute as soon as possible for *everything*.
 		BC_SIG_LOCK;
-
-#if BC_ENABLED
-		// If the first token is the keyword define, then we need to do this
-		// specially because bc thinks it may not be able to parse.
-		if (vm->prs.l.t == BC_LEX_KW_DEFINE) vm->parse(&vm->prs);
-#endif // BC_ENABLED
-
-		// Parse it all.
-		while (BC_PARSE_CAN_PARSE(vm->prs))
-		{
-			vm->parse(&vm->prs);
-		}
-
+		vm->parse(&vm->prs);
 		BC_SIG_UNLOCK;
 
 		// Execute if possible.
@@ -1028,7 +1008,6 @@ bc_vm_process(const char* text, bool is_stdin, bool is_exprs)
 		// Flush in interactive mode.
 		if (BC_I) bc_file_flush(&vm->fout, bc_flush_save);
 	}
-	while (vm->prs.l.t != BC_LEX_EOF);
 }
 
 #if BC_ENABLED
@@ -1045,6 +1024,7 @@ bc_vm_endif(void)
 	bc_parse_endif(&vm->prs);
 	bc_program_exec(&vm->prog);
 }
+
 #endif // BC_ENABLED
 
 /**
@@ -1061,6 +1041,8 @@ bc_vm_file(const char* file)
 
 	assert(!vm->sig_pop);
 
+	vm->mode = BC_MODE_FILE;
+
 	// Set up the lexer.
 	bc_lex_file(&vm->prs.l, file);
 
@@ -1076,7 +1058,7 @@ bc_vm_file(const char* file)
 	BC_SIG_UNLOCK;
 
 	// Process it.
-	bc_vm_process(data, false, false);
+	bc_vm_process(data, BC_MODE_FILE);
 
 #if BC_ENABLED
 	// Make sure to end any open if statements.
@@ -1084,6 +1066,7 @@ bc_vm_file(const char* file)
 #endif // BC_ENABLED
 
 err:
+
 	BC_SIG_MAYLOCK;
 
 	// Cleanup.
@@ -1121,7 +1104,7 @@ bc_vm_readLine(bool clear)
 		s = bc_read_line(&vm->line_buf, ">>> ");
 		vm->eof = (s == BC_STATUS_EOF);
 	}
-	while (!(s) && !vm->eof && vm->line_buf.len < 1);
+	while (s == BC_STATUS_SUCCESS && !vm->eof && vm->line_buf.len < 1);
 
 	good = (vm->line_buf.len > 1);
 
@@ -1137,12 +1120,14 @@ bc_vm_readLine(bool clear)
 static void
 bc_vm_stdin(void)
 {
+	bool clear;
+
 #if BC_ENABLE_LIBRARY
 	BcVm* vm = bcl_getspecific();
 #endif // BC_ENABLE_LIBRARY
 
-	vm->clear = true;
-	vm->is_stdin = true;
+	clear = true;
+	vm->mode = BC_MODE_STDIN;
 
 	// Set up the lexer.
 	bc_lex_file(&vm->prs.l, bc_program_stdin_name);
@@ -1167,18 +1152,18 @@ bc_vm_stdin(void)
 restart:
 
 	// While we still read data from stdin.
-	while (bc_vm_readLine(vm->clear))
+	while (bc_vm_readLine(clear))
 	{
 		size_t len = vm->buffer.len - 1;
 		const char* str = vm->buffer.v;
 
 		// We don't want to clear the buffer when the line ends with a backslash
 		// because a backslash newline is special in bc.
-		vm->clear = (len < 2 || str[len - 2] != '\\' || str[len - 1] != '\n');
-		if (!vm->clear) continue;
+		clear = (len < 2 || str[len - 2] != '\\' || str[len - 1] != '\n');
+		if (!clear) continue;
 
 		// Process the data.
-		bc_vm_process(vm->buffer.v, true, false);
+		bc_vm_process(vm->buffer.v, BC_MODE_STDIN);
 
 		if (vm->eof) break;
 		else
@@ -1256,11 +1241,14 @@ bc_vm_readBuf(bool clear)
 static void
 bc_vm_exprs(void)
 {
+	bool clear;
+
 #if BC_ENABLE_LIBRARY
 	BcVm* vm = bcl_getspecific();
 #endif // BC_ENABLE_LIBRARY
 
-	vm->clear = true;
+	clear = true;
+	vm->mode = BC_MODE_EXPRS;
 
 	// Prepare the lexer.
 	bc_lex_file(&vm->prs.l, bc_program_exprs_name);
@@ -1274,23 +1262,23 @@ bc_vm_exprs(void)
 	BC_SETJMP_LOCKED(vm, err);
 	BC_SIG_UNLOCK;
 
-	while (bc_vm_readBuf(vm->clear))
+	while (bc_vm_readBuf(clear))
 	{
 		size_t len = vm->buffer.len - 1;
 		const char* str = vm->buffer.v;
 
 		// We don't want to clear the buffer when the line ends with a backslash
 		// because a backslash newline is special in bc.
-		vm->clear = (len < 2 || str[len - 2] != '\\' || str[len - 1] != '\n');
-		if (!vm->clear) continue;
+		clear = (len < 2 || str[len - 2] != '\\' || str[len - 1] != '\n');
+		if (!clear) continue;
 
 		// Process the data.
-		bc_vm_process(vm->buffer.v, false, true);
+		bc_vm_process(vm->buffer.v, BC_MODE_EXPRS);
 	}
 
 	// If we were not supposed to clear, then we should process everything. This
 	// makes sure that errors get reported.
-	if (!vm->clear) bc_vm_process(vm->buffer.v, false, true);
+	if (!clear) bc_vm_process(vm->buffer.v, BC_MODE_EXPRS);
 
 err:
 
@@ -1299,6 +1287,10 @@ err:
 	// Cleanup.
 	bc_vm_clean();
 
+	// bc_program_reset(), called by bc_vm_clean(), resets the status.
+	// We want it to clear the sig_pop variable in case it was set.
+	if (vm->status == (sig_atomic_t) BC_STATUS_SUCCESS) BC_LONGJMP_STOP;
+
 	// Since this is tied to this function, free it here. We always free it here
 	// because bc_vm_stdin() may or may not use it later.
 	bc_vec_free(&vm->buffer);
@@ -1317,7 +1309,7 @@ static void
 bc_vm_load(const char* name, const char* text)
 {
 	bc_lex_file(&vm->prs.l, name);
-	bc_parse_text(&vm->prs, text, false, false);
+	bc_parse_text(&vm->prs, text, BC_MODE_FILE);
 
 	BC_SIG_LOCK;
 
@@ -1510,6 +1502,12 @@ bc_vm_boot(int argc, char* argv[])
 	const char* const env_clamp = BC_VM_DIGIT_CLAMP_STR;
 	int env_exit_def = BC_VM_EXPR_EXIT_DEF;
 	int env_clamp_def = BC_VM_DIGIT_CLAMP_DEF;
+	BcBigDig scale = BC_NUM_BIGDIG_MAX;
+	BcBigDig env_scale = BC_NUM_BIGDIG_MAX;
+	BcBigDig ibase = BC_NUM_BIGDIG_MAX;
+	BcBigDig env_ibase = BC_NUM_BIGDIG_MAX;
+	BcBigDig obase = BC_NUM_BIGDIG_MAX;
+	BcBigDig env_obase = BC_NUM_BIGDIG_MAX;
 
 	// We need to know which of stdin, stdout, and stderr are tty's.
 	ttyin = isatty(STDIN_FILENO);
@@ -1535,6 +1533,7 @@ bc_vm_boot(int argc, char* argv[])
 	bc_vm_gettext();
 
 #if BC_ENABLE_LINE_LIB
+
 	// Initialize the output file buffers.
 	bc_file_init(&vm->ferr, stderr);
 	bc_file_init(&vm->fout, stdout);
@@ -1543,6 +1542,7 @@ bc_vm_boot(int argc, char* argv[])
 	vm->buf = output_bufs;
 
 #else // BC_ENABLE_LINE_LIB
+
 	// Initialize the output file buffers. They each take portions of the global
 	// buffer. stdout gets more because it will probably have more data.
 	bc_file_init(&vm->ferr, STDERR_FILENO, output_bufs + BC_VM_STDOUT_BUF_SIZE,
@@ -1566,10 +1566,8 @@ bc_vm_boot(int argc, char* argv[])
 
 #if !BC_ENABLE_LIBRARY
 
-	// Initialize the slab vectors.
-	bc_slabvec_init(&vm->main_const_slab);
-	bc_slabvec_init(&vm->main_slabs);
-	bc_slabvec_init(&vm->other_slabs);
+	// Initialize the slab vector.
+	bc_slabvec_init(&vm->slabs);
 
 #endif // !BC_ENABLE_LIBRARY
 
@@ -1617,8 +1615,41 @@ bc_vm_boot(int argc, char* argv[])
 	}
 
 	// Process environment and command-line arguments.
-	bc_vm_envArgs(env_args);
-	bc_args(argc, argv, true, BC_PROG_SCALE(&vm->prog));
+	bc_vm_envArgs(env_args, &env_scale, &env_ibase, &env_obase);
+	bc_args(argc, argv, true, &scale, &ibase, &obase);
+
+	// This section is here because we don't want the math library to stomp on
+	// the user's given value for scale. And we don't want ibase affecting how
+	// the scale is interpreted. Also, it's sectioned off just for this comment.
+	{
+		BC_SIG_UNLOCK;
+
+		scale = scale == BC_NUM_BIGDIG_MAX ? env_scale : scale;
+#if BC_ENABLED
+		// Assign the library value only if it is used and no value was set.
+		scale = scale == BC_NUM_BIGDIG_MAX && BC_L ? 20 : scale;
+#endif // BC_ENABLED
+		obase = obase == BC_NUM_BIGDIG_MAX ? env_obase : obase;
+		ibase = ibase == BC_NUM_BIGDIG_MAX ? env_ibase : ibase;
+
+		if (scale != BC_NUM_BIGDIG_MAX)
+		{
+			bc_program_assignBuiltin(&vm->prog, true, false, scale);
+		}
+
+		if (obase != BC_NUM_BIGDIG_MAX)
+		{
+			bc_program_assignBuiltin(&vm->prog, false, true, obase);
+		}
+
+		// This is last to avoid it affecting the value of the others.
+		if (ibase != BC_NUM_BIGDIG_MAX)
+		{
+			bc_program_assignBuiltin(&vm->prog, false, false, ibase);
+		}
+
+		BC_SIG_LOCK;
+	}
 
 	// If we are in interactive mode...
 	if (BC_I)
