@@ -34,6 +34,8 @@ testdir=$(dirname "$script")
 
 . "$testdir/../scripts/functions.sh"
 
+outputdir=${BC_TEST_OUTPUT_DIR:-$testdir}
+
 # Command-line processing.
 if [ "$#" -lt 1 ]; then
 	printf 'usage: %s dir [exe [args...]]\n' "$0"
@@ -58,7 +60,7 @@ name="$testdir/$d/read.txt"
 results="$testdir/$d/read_results.txt"
 errors="$testdir/$d/read_errors.txt"
 
-out="$testdir/${d}_outputs/read_results.txt"
+out="$outputdir/${d}_outputs/read_results.txt"
 outdir=$(dirname "$out")
 
 # Make sure the directory exists.
