@@ -123,9 +123,11 @@ if [ ! -f "$results" ]; then
 	printf 'done\n'
 fi
 
-# We set this here because GNU dc does not have it.
-if [ "$d" = "dc" ]; then
-	options="-x"
+# We set this here because GNU bc and dc does not have these options.
+if [ "$d" = "bc" ]; then
+	options="-lqc"
+else
+	options="-xc"
 fi
 
 export $var=string
